@@ -5,7 +5,7 @@ function(counts,sample_sizes,k,loci){
 				mean_allele.frequencies[which(mean_allele.frequencies==0)] <- 0.01
 				mean_allele.frequencies[which(mean_allele.frequencies==1)] <- 0.99
 		mu_hat <- -log((1/mean_allele.frequencies)-1)
-			sd_mu_hat <- sd(mu_hat)
+			sd_mu_hat <- stats::sd(mu_hat)
 			beta_hat <- 1/(sd_mu_hat)^2			
 		mu_hat <- matrix(mu_hat,nrow=k,ncol=loci,byrow=TRUE)
 			allele.frequencies_hat[which(allele.frequencies_hat == 0)] <- 0.01
